#Code reference
This page show the files that in the pydagoras package that contribute to the `DAG_dot` base class.

__node.py__

class Node
::: pydagoras.node.Node

__dag.py__

class DAG
::: pydagoras.dag.DAG

__dag_dot.py__

class DAG_dot
::: pydagoras.dag_dot.DAG_dot
function calc
::: pydagoras.dag_dot.calc

